fnss.netconfig.nodeconfig.remove_application — FNSS 0.1.2 documentation

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.1.2 documentation »
- API Reference »
- Functions »

# fnss.netconfig.nodeconfig.remove_application

`remove_application`(topology, node, name=None)

  Remove an application from a node

  Parameters : | topology : Topology The topology object node : any hashable type The ID of the node from which the application is to be removed name : optional The name of the application to remove. If not given, all the applications of the node are removed

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.1.2 documentation »
- API Reference »
- Functions »